@@ -3,7 +3,7 @@ package Regexp::Pattern::Perl;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-06-16'; # DATE
 our $DIST = 'Regexp-Pattern-Perl'; # DIST
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 1;
 # ABSTRACT: Regexp patterns related to Perl
@@ -20,7 +20,17 @@ Regexp::Pattern::Perl - Regexp patterns related to Perl
 
 =head1 VERSION
 
-This document describes version 0.001 of Regexp::Pattern::Perl (from Perl distribution Regexp-Pattern-Perl), released on 2020-06-16.
+This document describes version 0.002 of Regexp::Pattern::Perl (from Perl distribution Regexp-Pattern-Perl), released on 2020-06-16.
+
+=head1 DESCRIPTION
+
+L<Regexp::Pattern> is a convention for organizing reusable regex patterns.
+
+=head1 PATTERNS
+
+=over
+
+=back
 
 =head1 HOMEPAGE
 
@@ -42,6 +52,10 @@ feature.
 
 L<Regexp::Pattern::CPAN>
 
+L<Regexp::Pattern>
+
+Some utilities related to Regexp::Pattern: L<App::RegexpPatternUtils>, L<rpgrep> from L<App::rpgrep>.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
